@@ -71,7 +71,7 @@ def process_atoms(load_template: Optional[bool] = True):
                 try:
                     template_dict = TemplateDict(ctx.obj["proj_path"].template)
                 except FileNotFoundError:
-                    click.secho("fatal: not a texproject folder", err=True)
+                    click.secho("error: not a texproject folder", err=True)
                     sys.exit(1)
             elif template is not None:
                 template_dict = NamedTemplateDict(template)
@@ -83,6 +83,7 @@ def process_atoms(load_template: Optional[bool] = True):
                 template_dict,
                 dry_run=ctx.obj["dry_run"],
                 verbose=ctx.obj["verbose"],
+                debug=ctx.obj["debug"],
             ).execute(ctx.invoke(f, *args, **kwargs), state_init=state_constructor)
 
         if load_template is False:
@@ -130,8 +131,9 @@ def process_atoms(load_template: Optional[bool] = True):
     help="Describe changes but do not execute",
 )
 @click.option("--verbose/--silent", "-v/-V", "verbose", default=True, help="Be verbose")
+@click.option("--debug/--no-debug", "debug", default=False, help="Debug mode")
 @click.pass_context
-def cli(ctx, proj_dir: Path, dry_run: bool, verbose: bool) -> None:
+def cli(ctx, proj_dir: Path, dry_run: bool, verbose: bool, debug: bool) -> None:
     """TexProject is a tool to help streamline the creation and distribution of files
     written in LaTeX.
     """
@@ -139,6 +141,7 @@ def cli(ctx, proj_dir: Path, dry_run: bool, verbose: bool) -> None:
         "proj_path": ProjectPath(proj_dir),
         "dry_run": dry_run,
         "verbose": verbose,
+        "debug": debug,
     }
 
 
@@ -348,23 +351,28 @@ def template() -> None:
 @_link_option(LinkMode.macro)
 @_link_option(LinkMode.citation)
 @_link_option(LinkMode.style)
-@click.option("--index", "index", help="position to insert", default=0, type=int)
+@click.option(
+    "--append/--prepend", "-a/-p", "append", default=True, help="append or prepend"
+)
 @process_atoms()
 def add(
     macros: List[str],
     citations: List[str],
     styles: List[str],
-    index: int,
+    append: bool,
 ) -> Iterable[AtomicIterable]:
-    """Add entries to the template dictionary. The --index option allows you to specify
-    the index to insert the citation (--index 0 means to insert at the beginning).
+    """Add entries to the template dictionary. Existing entries with the same name will
+    be replaced. To specify locations other than the end or beginning, run `tpr template
+    edit`.
     """
     for mode, names in [
         (LinkMode.macro, macros),
         (LinkMode.citation, citations),
         (LinkMode.style, styles),
     ]:
-        yield ApplyModificationSequence(AddCommand(mode, name, index) for name in names)
+        yield ApplyModificationSequence(
+            AddCommand(mode, name, append) for name in names
+        )
     yield TemplateDictWriter()
     yield TemplateDictLinker()
     yield InfoFileWriter()
@@ -586,10 +594,10 @@ def show(
         yield NameSequenceLinker(cmd, mode, names)
         yield PathSequenceLinker(cmd, mode, paths)
 
-    # if gitignore:
-    #     yield GitignoreWriter(force=True)
-    # if pre_commit:
-    #     yield PrecommitWriter(force=True)
+    if gitignore:
+        yield GitignoreWriter(force=True)
+    if pre_commit:
+        yield PrecommitWriter(force=True)
 
 
 @cli.command("list")
