@@ -7,6 +7,7 @@ import os
 import keyring
 
 from .control import AtomicIterable, RuntimeClosure, SUCCESS, FAIL
+from .error import AbortRunner
 from .filesystem import JINJA_PATH
 from .utils import run_command
 from .template import JinjaTemplate
@@ -16,7 +17,7 @@ import subprocess
 if TYPE_CHECKING:
     from .base import RepoVisibility
     from .filesystem import ProjectPath, TemplateDict
-    from typing import Iterable, Dict
+    from typing import Iterable, Dict, Optional
     from pathlib import Path
 
 
@@ -59,7 +60,7 @@ class InitializeGitRepo(AtomicIterable):
                 ["git", "add", "-A"],
                 ["git", "commit", "-m", "Initialize new texproject repository."],
             ]:
-                run_command(proj_path, command)
+                yield run_command(proj_path, command)
 
 
 @dataclass
@@ -77,16 +78,11 @@ class CreateGithubRepo(AtomicIterable):
         state: Dict,
         temp_dir: Path,
     ) -> Iterable[RuntimeClosure]:
-        org = proj_path.config.github.get("org", None)
         if git_has_remote(proj_path.dir):
             yield RuntimeClosure(
                 FORMAT_MESSAGE.error("Remote repository already exists!"), *FAIL
             )
         else:
-            if org is not None:
-                repo_name = f"{org}/{self.repo_name}"
-            else:
-                repo_name = self.repo_name
             gh_command = [
                 "gh",
                 "repo",
@@ -98,7 +94,7 @@ class CreateGithubRepo(AtomicIterable):
                 "--remote",
                 "origin",
                 "--push",
-                repo_name,
+                _format_repo_name(self.repo_name, proj_path),
                 "--" + self.visibility,
             ]
 
@@ -111,9 +107,35 @@ class CreateGithubRepo(AtomicIterable):
             yield run_command(proj_path, gh_command)
 
 
+def _format_repo_name(repo: str, proj_path: ProjectPath):
+    org = proj_path.config.github.get("org", None)
+    repo_parts = len(repo.split("/"))
+    if repo_parts == 2:
+        return repo
+    elif repo_parts == 1 and org is not None:
+        return f"{org}/{repo}"
+    else:
+        raise AbortRunner("Invalid remote repository name!")
+
+
+def get_repo_name_from_remote_url(path: Path):
+    # todo: fix this!
+    url_ret = subprocess.run(
+        ["git", "config", "--get", "remote.origin.url"], cwd=path, capture_output=True
+    )
+    if url_ret.returncode != 0:
+        raise AbortRunner("Could not read remote repository!")
+    url = url_ret.stdout.decode("ascii").strip()
+    print(url)
+    if url.startswith("git@github.com:") and url.endswith(".git"):
+        return url[15:-4]
+    else:
+        raise AbortRunner("Could not determine remote repository name!")
+
+
 @dataclass
 class WriteGithubApiToken(AtomicIterable):
-    repo_name: str
+    repo_name: Optional[str] = None
 
     def __call__(
         self,
@@ -131,7 +153,10 @@ class WriteGithubApiToken(AtomicIterable):
             token = Secret(user_token)
         except KeyError:
             token = None
-
+        if self.repo_name is None:
+            repo_name = get_repo_name_from_remote_url(proj_path.dir)
+        else:
+            repo_name = self.repo_name
         if token is not None:
             yield run_command(
                 proj_path,
@@ -143,7 +168,7 @@ class WriteGithubApiToken(AtomicIterable):
                     "-b",
                     token,
                     "-r",
-                    self.repo_name,
+                    _format_repo_name(repo_name, proj_path),
                 ],
             )
 
